==> libchipcard-kde-0.8.tar.gz: libchipcard-kde-0.8/src/kcardsetup/cfg_welcome.cpp <==
/***************************************************************************
 $RCSfile: cfg_welcome.cpp,v $
                             -------------------
    cvs         : $Id: cfg_welcome.cpp,v 1.4 2003/02/18 00:42:12 aquamaniac Exp $
    begin       : Wed Oct 09 2002
    copyright   : (C) 2002 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#include <qlabel.h>

#include "cfg_welcome.h"
#include "version.h"

#ifndef trUtf8
# define trUtf8 tr
#endif



ConfigWelcome::ConfigWelcome(QWidget* parent, const char* name, WFlags fl)
  :ConfigWelcomeBase(parent,name,fl)
  ,ConfigPage()
{
  string tmp;

  tmp="<qt>";
  tmp+="KCardSetup v"KCARDSETUP_VERSION_STRING"<br>";
  tmp+="Part of <font color=blue>LibChipCard v";
  tmp+=k_CHIPCARD_VERSION_STRING;
  tmp+="</font><br>";
  tmp+="(c) 2003 Martin Preuss<br>";
  tmp+="<font color=green>www.libchipcard.de</font>";
  tmp+="</qt>";
  lab_version->setText(tmp.c_str());
}


ConfigWelcome::~ConfigWelcome(){
}


bool ConfigWelcome::init(CONFIGGROUP *cfg){
  return true;
}


bool ConfigWelcome::save(CONFIGGROUP *cfg){
  return true;
}


bool ConfigWelcome::changed(){
    return false;
}

==> libchipcard-kde-0.9.tar.gz: libchipcard-kde-0.9/src/kcardsetup/cfg_welcome.cpp <==
/***************************************************************************
 $RCSfile: cfg_welcome.cpp,v $
                             -------------------
    cvs         : $Id: cfg_welcome.cpp,v 1.5 2003/03/31 02:43:25 aquamaniac Exp $
    begin       : Wed Oct 09 2002
    copyright   : (C) 2002 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#include <qlabel.h>

#include "cfg_welcome.h"
#include "version.h"

#ifndef trUtf8
# define trUtf8 tr
#endif



ConfigWelcome::ConfigWelcome(QWidget* parent, const char* name, WFlags fl)
  :ConfigWelcomeBase(parent,name,fl)
  ,ConfigPage()
{
  string tmp;

  tmp="<qt>";
  tmp+="KCardSetup v"KCARDSETUP_VERSION_STRING"<br>";
  tmp+="Using <font color=blue>LibChipCard v";
  tmp+=k_CHIPCARD_VERSION_STRING;
  tmp+="</font><br>";
  tmp+="(c) 2003 Martin Preuss<br>";
  tmp+="<font color=green>www.libchipcard.de</font>";
  tmp+="</qt>";
  lab_version->setText(tmp.c_str());
}


ConfigWelcome::~ConfigWelcome(){
}


bool ConfigWelcome::init(CONFIGGROUP *cfg){
  return true;
}


bool ConfigWelcome::save(CONFIGGROUP *cfg){
  return true;
}


bool ConfigWelcome::changed(){
    return false;
}
